@@ -1,20 +1,23 @@
 #pragma once
+
+#include <QDBusContext>
+#include <QObject>
 #include <QSharedPointer>
 
-#include "displays/output-manager/mode/WaylandOutputMetaMode.hpp"
-#include "generated/OutputModeAdaptorGen.h"
+#include "outputs/wlr/metamode.hpp"
 
 namespace bd {
-  class OutputModeService : public QObject {
+  class OutputModeService : public QObject, protected QDBusContext {
       Q_OBJECT
       Q_PROPERTY(int Width READ Width)
       Q_PROPERTY(int Height READ Height)
       Q_PROPERTY(qulonglong RefreshRate READ RefreshRate)
       Q_PROPERTY(bool Preferred READ Preferred)
       Q_PROPERTY(bool Current READ Current)
+
     public:
-      OutputModeService(QSharedPointer<WaylandOutputMetaMode> mode, const QString& outputId, QObject* parent = nullptr);
-      ~OutputModeService();
+      explicit OutputModeService(QSharedPointer<bd::Outputs::Wlr::MetaMode> mode, const QString& outputId, QObject* parent = nullptr);
+      ~OutputModeService() = default;
 
       // Property getters
       int        Width() const;
@@ -27,9 +30,8 @@ namespace bd {
       Q_INVOKABLE QVariantMap GetModeInfo();
 
     private:
-      QSharedPointer<WaylandOutputMetaMode> m_mode;
-      OutputModeAdaptor*                    m_adaptor;
-      QString                               m_outputId;
-      bool                                  isCurrentMode() const;
+      QSharedPointer<bd::Outputs::Wlr::MetaMode> m_mode;
+      QString                                    m_outputId;
+      bool                                       isCurrentMode() const;
   };
 }
